@@ -1,11 +1,13 @@
 """ World Status Get Command Definition """
 
-import requests
-from requests import Response
+from starlette import status
 
-from rowantree.common.sdk import demand_env_var, demand_env_var_as_float
+from rowantree.common.sdk import demand_env_var
 from rowantree.contracts import WorldStatus
 
+from ..contracts.dto.request_status_codes import RequestStatusCodes
+from ..contracts.dto.wrapped_request import WrappedRequest
+from ..contracts.request_verb import RequestVerb
 from .abstract_command import AbstractCommand
 
 
@@ -20,7 +22,7 @@ class WorldStatusGetCommand(AbstractCommand):
         Executes the command.
     """
 
-    def execute(self, headers: dict[str, str]) -> WorldStatus:
+    def execute(self) -> WorldStatus:
         """
         Executes the command.
 
@@ -28,13 +30,12 @@ class WorldStatusGetCommand(AbstractCommand):
         -------
         world_status: WorldStatus
             The world status.
-        headers: dict[str, str]
-            Request headers
         """
 
-        response: Response = requests.get(
+        request: WrappedRequest = WrappedRequest(
+            verb=RequestVerb.GET,
             url=f"{demand_env_var(name='ROWANTREE_SERVICE_ENDPOINT')}/v1/world",
-            headers=headers,
-            timeout=demand_env_var_as_float(name="ROWANTREE_SERVICE_TIMEOUT"),
+            statuses=RequestStatusCodes(allow=[status.HTTP_200_OK], reauth=[status.HTTP_401_UNAUTHORIZED], retry=[]),
         )
-        return WorldStatus.parse_obj(response.json())
+        response: dict = self.wrapped_request(request=request)
+        return WorldStatus.parse_obj(response)
